--[[
	Loads all sound effects
	Caveware Digital :: 2017
]]


local Sound = {}
Sound.__index = Sound


function Sound:play()
	self._current = (self._current % self._buffers) + 1
	self._sources[self._current]:stop()
	self._sources[self._current]:play()
end

function Sound:stop()
	for key, source in ipairs(self._sources) do
		source:stop()
	end
end


local function newSound(sound_data, buffers)
	local t = {}
	setmetatable(t, Sound)

	t._buffers = buffers or 4
	t._current = 0
	t._sources = {}

	for i = 1, t._buffers do
		table.insert(t._sources, love.audio.newSource(sound_data))
	end

	return t
end


--[[
	Recursively checks a folder for sounds and adds any found to a table
	INPUT: Directory and table or nil
	OUTPUT: Table of loaded assets
]]
local function loadSFXFolder(dir, tab)
	-- Create new table or use given
	local tab = tab or newExtendedTable({})

	-- Get a table of files / subdirs from dir
	local items = love.filesystem.getDirectoryItems(dir)

	for key, val in ipairs(items) do
		if (love.filesystem.isFile(dir .. "/" .. val)) then
			if (val ~= "init.lua") then
				-- Remove ".ogg" extension on file
				name = val:sub(1, -5)

				-- Load sound into table
				tab[name] = newSound(love.sound.newSoundData(dir .. "/" .. val))
			end
		else
			-- Add new table onto tab
			tab[val] = newExtendedTable({})

			-- Run checkFolder in this subdir
			loadSFXFolder(dir .. "/" .. val, tab[val])
		end
	end

	return tab
end


-- Load the sfx folder
local sfx = loadSFXFolder(...)


return sfx
