local Dialogue = {
	_is_active = false
}


--[[
	(string)
	Display given text

	(function)
	Calculate text to Display

	(table)
	First value is string to show, second value is table of options to show
]]


function Dialogue:update(dt)
	if (self._is_active) then
		self._revealer = math.min(self._revealer + dt * 150, #self._text)

		-- Progress if action button pressed
		if (InputManager:wasPressed("action")) then
			self:progress()
			InputManager:claimWasPressed("action")
		end

		-- Modify option if up or down is pressed
		local up_or_down =
			InputManager:wasPressed("up") or InputManager:wasPressed("down")
		if (self._options and up_or_down) then
			sfx.menu_move:play()
			self._option = self._option % 2 + 1
		end
	end
end


function Dialogue:draw()
	if (self._is_active) then
		love.graphics.setColor(255, 255, 255)
		love.graphics.setFont(fonts.text)

		if (self._show_at_bottom) then
			love.graphics.draw(gfx.gui.dialogue_long, 2, 160)
		else
			love.graphics.draw(gfx.gui.dialogue, 94, 2)
		end

		local text = string.sub(self._text, 1, math.min(self._revealer))
		if (self._revealer == #self._text) then
			if (self._show_at_bottom) then
				love.graphics.draw(gfx.gui.dialogue_long_arrow, 2, 160)
			else
				love.graphics.draw(gfx.gui.dialogue_arrow, 94, 2)
			end

			if (self._options) then
				for key, value in ipairs(self._options) do
					text = text .. (key == self._option and "\n> " or "\n  ")
					text = text .. value[1]
				end
			end
		end
		if (self._show_at_bottom) then
			love.graphics.printf(text, 11, 170, 234, "left")
		else
			love.graphics.printf(text, 103, 12, 142, "left")
		end

		if (self._speaker ~= "") then
			love.graphics.draw(gfx.gui.dialogue_name, 2, 8)
			love.graphics.print(self._speaker, 10, 17)
		end
	end
end


function Dialogue:isActive()
	return self._is_active
end


function Dialogue:progress()
	if (self._revealer ~= #self._text) then
		self._revealer = #self._text
		return
	end

	self._key = self._key + 1

	if (self._key > #self._steps and not self._options) then
		self._is_active = false
	else
		self:showStep(self._key)
	end
end


function Dialogue:set(dialogue_table, speaker, show_at_bottom)
	self._key = 1
	self._options = nil
	self._revealer = 0
	self._show_at_bottom = show_at_bottom
	self._speaker = speaker or ""
	self._steps = dialogue_table
	self:showStep(self._key)
	self._is_active = true
end


function Dialogue:showStep(step_to_show)
	if (self._options) then
		self._options[self._option][2]()
		return
	end

	local step =self._steps[step_to_show]

	if (type(step) == "function") then
		step = step()
	end

	self._revealer = 0

	if (type(step) == "table") then
		self._option = 1
		self._options = step[2]
		self._text = step[1]
	elseif (step) then
		self._text = step
	else
		self._is_active = false
	end
end


return Dialogue
