local EssenceMenu = {
	_is_active = false,
	_held_essences = newExtendedTable({
		'parasite'
	}),
	_essence_details = {
		guard_2 = {
			title = "Guard",
			description = "The portly gatekeeper of Ward A of this prison."
		},
		parasite = {
			title = "Parasite",
			description = "Little wormy dude that kills people. This is you."
		},
		scientist = {
			title = "Dr. Bosco",
			description = "Your late creator."
		},
		prisoner_3 = {
			title = "Charles",
			description = "Just some kid. Don't know why he's here."
		},
		prisoner_4 = {
			title = "Basket Boy",
			description = "Future basketball star? Dunno"
		},
		prisoner_8 = {
			title = "Henk",
			description = "Who is he? He's the cook."
		},
	}
}


function EssenceMenu:add(type)
	self._held_essences:insert(type)
	self._held_essences:sort(function (a, b)
		return self._essence_details[a].title < self._essence_details[b].title
	end)
end


function EssenceMenu:isActive()
	return self._is_active
end


function EssenceMenu:has(type)
	return self._held_essences:contains(type)
end


function EssenceMenu:open()
	self._is_active = true

	for key, value in ipairs(self._held_essences) do
		if (value == Player:getMode()) then
			self.selected = key
		end
	end
end


function EssenceMenu:update(dt)
	if (self._is_active) then
		if (InputManager:wasPressed("back")) then
			self._is_active = false
		end

		if (InputManager:wasPressed("down")) then
			sfx.menu_move:play()
			self.selected = (self.selected % #self._held_essences) + 1
		end

		if (InputManager:wasPressed("up")) then
			sfx.menu_move:play()
			self.selected = self.selected - 1
			if (self.selected == 0) then
				self.selected = #self._held_essences
			end
		end

		if (InputManager:wasPressed("action")) then
			self._is_active = false
			if (Player:getMode() ~= self._held_essences[self.selected]) then
				Player:startTransformation(self._held_essences[self.selected])
			end
			InputManager:claimWasPressed("action")
		end
	end
end


function EssenceMenu:draw()
	if (self._is_active) then
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(gfx.gui.essences)

		local text = ''
		for key, value in ipairs(self._held_essences) do
			if (key == self.selected) then
				text = text .. "> "
			end

			local current_key = self._held_essences[key]
			local essence_details = self._essence_details[current_key]
			text = text .. essence_details.title .. "\n"
		end

		love.graphics.print(text, 11, 11)

		local key = self._held_essences[self.selected]
		love.graphics.draw(gfx.essences[key],
			160, 48)
		love.graphics.printf(self._essence_details[key].description, 142, 116, 104, "left")
	end
end


return EssenceMenu
