local NPC = {}
NPC.__index = NPC


function NPC:new(x, y, w, h, options)
	local new_npc = {}
	local options = options or {}
	setmetatable(new_npc, self)

	if (options.will_face) then
		new_npc._facing = "down"
	end

	-- Set flags
	new_npc._is_talkable = options.talkable or true
	new_npc._y_offset = options.y_offset or 0

	-- Set position and sizing
	new_npc._x = x
	new_npc._y = y - new_npc._y_offset
	new_npc._w = w
	new_npc._h = h

	return new_npc
end


function NPC:draw()
	local x_off = self._x_offset or 0
	local y_off = self._y_offset or 0
	local image = self:getImage()
	if (type(image) == "table") then
		image = image["idle_" .. self._facing]
	end
	love.graphics.draw(image, self._x + x_off, self._y + y_off)
end



function NPC:getCollisionBox()
	return {
		x = self._x,
		y = self._y,
		w = self._w,
		h = self._h
	}
end


function NPC:getDirectionOfPlayer()
	local x, y = Player._x, Player._y
	if (x > self._x) then
		return "right"
	elseif (x < self._x) then
		return "left"
	elseif (y > self._y) then
		return "down"
	else
		return "up"
	end
end


function NPC:getImage()
	return gfx.char.parasite.idle_right
end


function NPC:isTalkable()
	return self._is_talkable
end


function NPC:update(dt)

end


function NPC:uponUse()
	self._facing = self:getDirectionOfPlayer()
end


return NPC
