--[[
	Play state
	Caveware Digital :: 2017
]]


local current_folder = ...
local CutsceneState = {}


--[[
	Initialises the play state
	INPUT: options - Default settings for this state
]]
function CutsceneState:start(options)
	self._step = 1
	self._steps = options
	self._tx, self._ty = 0, 0

	local step = self._steps[self._step]
	self._first_start = false
	self._map = step.map
end


--[[
	Performed upon this state being popped
]]
function CutsceneState:stop()
	-- Kill everything about this state
end


--[[
	Update each loop
	INPUT: dt - Delta time
]]
function CutsceneState:update(dt)
	local current_step = self._steps[self._step]

	if (not self._first_start) then
		current_step.start()
		self._first_start = true
	end

	if (current_step.update) then
		current_step.update(dt)
	end

	if (current_step.check()) then
		self._step = self._step + 1

		if (self._step > #self._steps) then
			StateManager:pop()
		else
			self._steps[self._step].start()
		end
	end
end


--[[
	Draws
]]
function CutsceneState:draw()
	love.graphics.translate(math.round(self._tx), math.round(self._ty))

	local step = self._steps[self._step]

	-- Map must be drawn
	if (step.map) then
		MapTool.draw(step.map)
	end

	if (step.bg) then
		love.graphics.draw(step.bg)
	end

	if (step.draw) then
		step.draw()
	end

	if (step.map) then
		MapTool.drawFG(step.map)
	end

	love.graphics.translate(-math.round(self._tx), -math.round(self._ty))
end




function CutsceneState:loadMap(map_to_load, checkpoint)
end


function CutsceneState:setMap(map_to_load)
	self.current_map = map_to_load
end


return CutsceneState
