--[[
	Play state
	Caveware Digital :: 2017
]]


local current_folder = ...
local MainState = {}


--[[
	Initialises the play state
	INPUT: options - Default settings for this state
]]
function MainState:start(options)
	self._in_timer = 0
	self._timer = 0

	bgm.title:play()
end


--[[
	Performed upon this state being popped
]]
function MainState:stop()
	-- Kill everything about this state
	bgm.title:stop()
end


--[[
	Update each loop
	INPUT: dt - Delta time
]]
function MainState:update(dt)
	self._timer = self._timer + dt
	self._in_timer = math.min(1, self._in_timer + dt)

	if (InputManager:wasPressed("action") and not self._out_timer) then
		self._out_timer = 1
	end

	if (self._out_timer) then
		self._out_timer = self._out_timer - dt

		if (self._out_timer <= 0) then
			StateManager:pop()
			StateManager:push("cutscene", cutscenes.intro)
		end
	end
end


--[[
	Draws
]]
function MainState:draw()
	love.graphics.setColor(255, 255, 255, 255 * (self._out_timer or self._in_timer))

	if (self._timer < 3.5) then
		love.graphics.draw(gfx.bg.title_1)
	else
		love.graphics.draw(gfx.bg["title_" .. math.floor(self._timer % 2 + 3)])
	end

	if (self._timer >= 3 and self._timer < 4) then
		local alpha = math.abs(((self._timer - 3) * 2) - 1)
		love.graphics.setColor(255, 255, 255, (255 * (1 -alpha)))
		love.graphics.rectangle("fill", 0, 0, Flags.GAME_WIDTH, Flags.GAME_HEIGHT)
	end
end


return MainState
