--[[
	ColourTool controller
	Caveware Digital :: 2017
]]


local ColourTool = {
	_list = require(... .. "/colour_list")
}


--[[
	Blends two colours
]]
function ColourTool:blend(colour_1, colour_2, distance)
	-- Load colours from the internal list
	colour_1 = self:get(colour_1)
	colour_2 = self:get(colour_2)

	-- Add fourth channel if not supplied, and default distance to 0.5
	colour_1[4] = colour_1[4] or 255
	colour_2[4] = colour_2[4] or 255
	distance = distance or 0.5

	-- Blend colours
	local blended_colour = {}
	for i = 1, 4 do
		local difference = colour_2[i] - colour_1[i]
		blended_colour[i] = colour_1[i] + difference * distance
	end

	return blended_colour
end


--[[
	Retrieves a colour from the internal list given a key
	INPUT: colour - The key of the colour from the internal list or colour table
	OUTPUT: ColourTool retrieved from the list
]]
function ColourTool:get(colour)
	return type(colour) == "string" and self._list[colour] or colour
end


return ColourTool
