--[[
	Psychic prison
	Caveware Digital :: 2017
]]

-- Constants
GRID_SIZE = 16


if (Flags.GAME_PIXEL_BASED) then
	love.graphics.setDefaultFilter('nearest')
end


require("libs")
require("extensions")
require("helpers")
require("assets")
require("entities")


--[[
	Loads the initial game state
]]
function love.load()
	InputManager:load()
	ScaleManager:load()

	-- Add the splash screen as the first state
	StateManager:push("play", {
		next_state = "play"
	})
	StateManager:push("main")
end


function love.update(dt)
	-- Update Lovebird if in development mode
	if (Flags.DEVELOPMENT) then
		lovebird.update()
	end

	-- Limit FPS lower limit to 15 to save calculations
	dt = math.min(dt, 1 / 15)

	InputManager:update()
	CutsceneController:update(dt)
	Dialogue:update(dt)
	EssenceMenu:update(dt)

	-- Updates all timers
	TimerManager:update(dt)

	local paused =
		Dialogue:isActive() or
		EssenceMenu:isActive() or
		CutsceneController:isActive()

	if (not paused) then
		-- Update the current state
		StateManager:update(dt)
	end
end


function love.draw()
	love.graphics.setFont(fonts.text)

	-- Draw the current state
	ScaleManager:draw(function ()
		StateManager:draw()
		CutsceneController:draw()
		Dialogue:draw()
		EssenceMenu:draw()
	end)
end
